diff options
| author | ReinUsesLisp <reinuseslisp@airmail.cc> | 2020-04-14 01:34:20 -0300 |
|---|---|---|
| committer | ReinUsesLisp <reinuseslisp@airmail.cc> | 2020-04-14 01:34:20 -0300 |
| commit | ab33a2bebc6e2b48ba0315cbbd944d375819454f (patch) | |
| tree | 29512449b22713a2afe043852b889e4414b72d61 /src/core/loader/loader.cpp | |
| parent | f2f2262c5e3ea25747e56cf716dfcfdc4969ab52 (diff) | |
gl_shader_cache: Use CompileDepth::FullDecompile on GLSL
From my testing on a Splatoon 2 shader that takes 3800ms on average to
compile changing to FullDecompile reduces it to 900ms on average.
The shader decoder will automatically fallback to a more naive method if
it can't use full decompile.
Diffstat (limited to 'src/core/loader/loader.cpp')
0 files changed, 0 insertions, 0 deletions
